/*
 * Copyright (c) 2019 UPLEX Nils Goroll Systemoptimierung
 * All rights reserved
 *
 * Author: Geoffrey Simmons <geoffrey.simmons@uplex.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package apiclient

import api_v1 "k8s.io/api/core/v1"

func (worker *NamespaceWorker) syncCfgMap(key string) error {
	worker.log.Infof("Syncing ConfigMap: %s/%s", worker.namespace, key)
	return worker.updater.Update()
}

func (worker *NamespaceWorker) addCfgMap(key string) error {
	return worker.syncCfgMap(key)
}

func (worker *NamespaceWorker) updateCfgMap(key string) error {
	return worker.syncCfgMap(key)
}

func (worker *NamespaceWorker) deleteCfgMap(obj interface{}) error {
	worker.updater.ClearVCL()
	cfgMap, ok := obj.(*api_v1.ConfigMap)
	if !ok || cfgMap == nil {
		worker.log.Warnf("Delete ConfigMap: not found: %v", obj)
		return nil
	}
	worker.log.Infof("Delete ConfigMap %s/%s: no sync action taken",
		cfgMap.Namespace, cfgMap.Name)
	return nil
}
